<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Repetir: Todo</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Repetir: Pista</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Reproduciendo.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Cargando reproducción.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Reproducción en pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Error de salida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Reproducción parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Reproducción finalizada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Error de decodificación.</translation>
    </message>
</context>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Select music to be played:</source>
        <translation type="obsolete">Seleccione la música a escuchar:</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>Copiar a una nueva lista de reproducción</translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>Borrar la cola de reproducción activa</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation>Guardar la lista</translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>Mover a la cola de reproducción activa</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>Borrar esta lista de reproducción</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>Renombrar esta lista de reproducción</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Cola de reproducción activa</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Todas mis listas</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Toda mi música</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation>blah blah blah</translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>Toda mi música ~ Cargando datos de música</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>Cargando datos de música</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation type="unfinished">Género:</translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation type="unfinished">Varios artistas</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>Shuffle Mode</source>
        <translation type="obsolete">Modo aleatorio</translation>
    </message>
    <message>
        <source>Repeat Mode</source>
        <translation type="obsolete">Modo de repetición</translation>
    </message>
    <message>
        <source>Edit Playlist</source>
        <translation type="obsolete">Editar Lista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="obsolete">Visualizar</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Puntuación</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="obsolete">Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Título</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Duración</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Repetir: Pista</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Repetir: Todo</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Reproduciendo.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Cargando reproducción.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Reproducción en pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Error de salida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Reproducción parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Reproducción finalizada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Error de decodificación.</translation>
    </message>
    <message>
        <source>Shuffle: Intelligent</source>
        <translation type="obsolete">Aleat.: Inteligente</translation>
    </message>
    <message>
        <source>Shuffle: Random</source>
        <translation type="obsolete">Aleatorio: Casual</translation>
    </message>
    <message>
        <source>1 Shuffle: Intelligent</source>
        <translation type="obsolete">1 Aleat.: Inteligente</translation>
    </message>
    <message>
        <source>1 Shuffle: Random</source>
        <translation type="obsolete">1 Aleatorio: Casual</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="obsolete">1 Aleatorio: No</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="obsolete">Aleatorio: No</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="obsolete">2 Repetir: Todo</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="obsolete">2 Repetir: Pista</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="obsolete">2 Repetir: No</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="obsolete">Repetir: No</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="obsolete">3 Editar Lista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="obsolete">4 Visualizar</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="obsolete">1 Aleatorio: Preferido</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="obsolete">Aleatorio: Preferido</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="obsolete">1 Aleatorio: Variable</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="obsolete">Aleatorio: Variable</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="obsolete">raiz de la lista</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="unfinished">Editar Lista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="unfinished">Visualizar</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="unfinished">3 Editar Lista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="unfinished">4 Visualizar</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="unfinished">1 Aleatorio: Preferido</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="unfinished">Aleatorio: Preferido</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="unfinished">1 Aleatorio: Variable</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="unfinished">Aleatorio: Variable</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="unfinished">1 Aleatorio: No</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="unfinished">Aleatorio: No</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="unfinished">2 Repetir: Todo</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="unfinished">Repetir: Todo</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="unfinished">2 Repetir: Pista</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="unfinished">Repetir: Pista</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="unfinished">2 Repetir: No</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="unfinished">Repetir: No</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="unfinished">raiz de la lista</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="unfinished">Reproduciendo.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="unfinished">Cargando reproducción.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="unfinished">Reproducción en pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="unfinished">Error de salida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="unfinished">Reproducción parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="unfinished">Reproducción finalizada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="unfinished">Error de decodificación.</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Searching for music files</source>
        <translation>Buscando archivos de música</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>Actualizando la base de datos</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Varios artistas</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>Directorio que contiene la música</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation>ESte directorio debe de existir y el usuario de MythMusic requiere acceso en escritura sobre el mismo.</translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation>Dispositivo de áudio</translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation>Dispositivo de audio para la reproducción.</translation>
    </message>
    <message>
        <source>CD device</source>
        <translation>Dispositivo de CD</translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation>CDRom a usar en la reproducción y ripeado.</translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation>Ordenación del árbol</translation>
    </message>
    <message>
        <source>Order in which to sort the Music Selection Tree. Possible values are space-separated list of genre, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the actual directory tree.</source>
        <translation type="obsolete">Ordenación de la selección de música. Los valores se separan por espacios en blanco entre &apos;list&apos;, &apos;genre&apos;, &apos;artist&apos;, &apos;album&apos; y &apos;title&apos; o la palabra clave &apos;directory&apos; para indicar que se use el árbol de directorios dentro del arbol.</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>nombre del script</translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation>Si se encuentra presente, será ejecutada al completar el ripeado de un CD.</translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation>Formato del nombre de archivo</translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation>Formato del nombre de archivo empleado para reconocer información cuando no se encuentran marcas ID3.</translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation>Ignorar marcas ID3</translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation>Si se activa, MythMusic no comprueba las marcas ID3 en los archivos y simplemente determina el gènero, artista, álbum, número de pista y tíyulo por el nombre de archivo.</translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation>Mira automáticamente los CDs</translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation>Automáticamente mira si los CD de audio están presentes y visualiza la información en el árbol de selección.</translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation>Usa teclas rápidas</translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation>Si no esta activo, necesitará las flechas de cursor para seleccionar y activar varias funciones.</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Compresión</translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation></translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation></translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation>Códec para el ripeado de CDs. La calidad &apos;Perfecta&apos; usará el códec FLAC.</translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation>Lugar de almacenamiento de archivos</translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation>Define donde se guardarán las nuevas canciones. Los valores posibles son GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / y -. El &apos;-&apos; se sustituirá por la marca de separación</translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation>Marca de separación</translation>
    </message>
    <message>
        <source> - </source>
        <translation>-</translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation>Los archovos se separarán con esta marca.</translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation>Sustituye &apos; &apos; con &apos;_&apos;</translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation>Si se activa, los espacios en blanco en los nombres de archivo se sustituyen por subrayados.</translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation>Nivel de Paranoia</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <source>Faster</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation>Nivel de Paranoia del ripeador. Póngalo a Rápido si no le preocupan posibles errores en el audio.</translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation>Expulsar automáticamente el CD después del ripeado</translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation>Si se activa, la bandeja del CD se abrirá automáticamente una vez finalice el proceso de ripeado.</translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation>Peso de puntuación</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation>En la reproducción en modo &quot;Preferidos&quot;. Este peso afecta a la puntuación asignada a su puntuación de una canción determinada en el momento de ordenarla.</translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation>Peso del contador de reproducciones</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation>En la reproducción en modo &quot;Preferidos&quot;. Este peso afecta a la puntuación asignada según el número de veces que se ha reproducido.</translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation>Última reproducción</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation>En la reproducción en modo &quot;Preferidos&quot;. Este peso afecta a la puntuación según lo reciente de su última reproducción.</translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation>Peso aleatorio</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation>En la reproducción en modo &quot;Preferidos&quot;. Este peso afecta a la puntuación de forma aleatroria en el momento de ordenar las canciones.</translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation>Ver las puntuaciones</translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation>Ver las puntuaciones en la pantalla de reproducción.</translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation>Orden de Listado</translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation>Listar las canciones en el mismo orden que van a reproducirse.</translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation>Ver el árbol completo</translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation>Si se activa, podrá navegar en el árbol de música durante la reproducción.</translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation>Modo de reproducción</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation></translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatorio</translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation>Inteligente</translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation>Modo inicial de reproducción. Puede ser normal, aleatorio o inteligente.</translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation>Tiempo de espera para iniciar visualizaciones (segundos)</translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation>Si se pone 0, las visualizaciones no se iniciarán nunca.</translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation>Cambiar de visualización en cada canción</translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation>Cambiar el visualizador cuando tambén se cambia de canción.</translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation>Ancho de escala de visualización</translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation>Si se pone valor &quot;2&quot;, las visualizaciones se reducitán a la mitad. Actualmente solo esta disponible en la visualización &quot;goom&quot;. Reduce el consumo de procesador en sistemas lentos.</translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation>Altura de la visualización</translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation>Visualizaciones</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation>Lista de visualizaciones durante la reproducción. Los valores posibles se separan con espacios en blanco de </translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation></translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation></translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation></translation>
    </message>
    <message>
        <source>Goom</source>
        <translation></translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation></translation>
    </message>
    <message>
        <source>Gears</source>
        <translation></translation>
    </message>
    <message>
        <source>Blank</source>
        <translation></translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation>Calidad de ripeado por defecto</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecta</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation>Calidad por defecto de ripeado en CDs nuevos.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuración General</translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation>Configuración de reproducción</translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation>Configuración de visualización</translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation>Configuración del ripeador</translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation></translation>
    </message>
    <message>
        <source>music database</source>
        <translation type="obsolete">Base de Datos de música</translation>
    </message>
    <message>
        <source>cd ripper</source>
        <translation type="obsolete">ripeador</translation>
    </message>
    <message>
        <source>

You have no MythMusic tables in your database.</source>
        <translation type="obsolete">No tiene las tablas de MythMusic en su Base de Datos.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll read the documentation</source>
        <translation type="obsolete">Bien, leeré la documentación</translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation>Artista desconocido</translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation>Álbum desconocido</translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation>Género desconocido</translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation>CD -- ninguno</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Toda mi música</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>title</source>
        <translation>título</translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation>Flta entrada en la base de datos: %1</translation>
    </message>
    <message>
        <source> ~ </source>
        <translation></translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation>Uuups</translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation>Sin inicializar</translation>
    </message>
    <message>
        <source>oops</source>
        <translation>uups</translation>
    </message>
    <message>
        <source>,%1</source>
        <translation></translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Todas mis listas</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Lista de reproducción activa</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation>Lista de reproducción activa (%1)</translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation>Algo va mal</translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation>La visualización requiere la librería FFT</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation>Ejecutó &apos;configure&apos;?</translation>
    </message>
    <message>
        <source>and</source>
        <translation> y </translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>Por favor seleccione un nivel de calidad y compruebe la información del álbum:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecta</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>Importar este CD</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>Importando CD:
</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>Copiando de CD:
</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Género:</translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>Ripeando...</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Duración</translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>Aguarde un momento...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
